@@ -1059,8 +1059,15 @@ class FormElementPlugin(BasePlugin):
             return return_func_results
 
         # Get form field instances (as defined by ``get_form_field_instances``
-        # methods in plugins)
-        form_field_instances = self.get_form_field_instances()
+        # methods in plugins). In DEBUG mode raise an exception if something
+        # goes wrong. Otherwise - skip the element.
+        try:
+            form_field_instances = self.get_form_field_instances()
+        except AttributeError as e:
+            if DEBUG:
+                raise e
+            else:
+                return []
 
         # Data to update field instance kwargs with
         kwargs_update = self.get_origin_kwargs_update_func_results(
@@ -1360,9 +1367,9 @@ class BaseRegistry(object):
         """
         if not issubclass(cls, self.type):
             raise InvalidRegistryItemType(
-            "Invalid item type `{0}` for registry "
-            "`{1}`".format(cls, self.__class__)
-            )
+                "Invalid item type `{0}` for registry "
+                "`{1}`".format(cls, self.__class__)
+                )
 
         # If item has not been forced yet, add/replace its' value in the
         # registry.
